@@ -17,7 +17,7 @@ field allowed_robots => sub { shift->cfg->allowed_robots };
 
 sub handle {
 	my $req = new UvT::Kiki::ACL::Request(ctx => shift, cfg => $self);
-	die UvT::Kiki::ACL::Document(req => $req)->new->response
+	die UvT::Kiki::ACL::Document->new(req => $req)->response
  		unless $req->authorized;
 	my $res = super($req, @_);
 	$res->setcookie(session => $req->session, HttpOnly => 1, Secure => $req->secure)
