@@ -1,4 +1,4 @@
-# $Id: Transaction.pm 48567 2019-12-12 16:22:55Z wsl $
+# $Id: Transaction.pm 51832 2024-11-29 16:02:27Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/Database/Transaction.pm $
 
 use re '/aa';
@@ -12,6 +12,9 @@ use UvT::Kiki::Database::Domain;
 
 use Clarity -self;
 
+use constant true => !undef;
+use constant false => !true;
+
 field db;
 field cfg;
 
@@ -137,7 +140,7 @@ sub create_alias {
 
 sub exists_alias {
 	my ($local, $domain) = @_;
-	
+
 	my $res = $self->query('SELECT EXISTS(SELECT * FROM mail_aliases WHERE lower(mail_aliases.name) = lower(?) AND mail_aliases.domain = ?)', $local, $domain->id);
 	return $res->[0][0];
 }
@@ -189,6 +192,14 @@ sub tentative_label {
 	return new UvT::Kiki::Database::Alias(db => $self, localpart => $local, domain => $domain, addressbook => 0);
 }
 
+sub undef_eq() {
+	# Either both are undef or they are equal:
+	my ($a, $b) = @_;
+	return defined $a
+		? defined $b && $a eq $b
+		: !defined $b;
+}
+
 sub upsert_person {
 	my $person = shift;
 	my $anr = $person->anr;
@@ -206,7 +217,7 @@ sub upsert_person {
 
 		my $mailbox = $person->mailbox;
 		$self->perform('UPDATE persons SET mailaddress = ? WHERE person = ?', $mailbox, $anr)
-			unless $original->mailbox eq $mailbox;
+			unless undef_eq($original->mailbox, $mailbox);
 	} else {
 		$self->perform('INSERT INTO persons (person, mailaddress) VALUES (?, ?)', $anr, $person->mailbox);
 	}
@@ -458,7 +469,7 @@ sub search_alias {
 	my $escaped = $query;
 	$escaped =~ s/([%_])/\\$1/g;
 
-	my %parts; 
+	my %parts;
 	@parts{split(' ', lc($query))} = ();
 	return [] unless %parts;
 
@@ -477,7 +488,7 @@ sub search_alias {
 			push @substring_parts, $_;
 			s/([%_\\])/\\$1/g;
 			push @substring_where, "%$_%";
-		}	
+		}
 	}
 
 	my @domain_where = "a.domain IN (".join(', ', sort keys %domain_parts).")" if %domain_parts;
