@@ -70,6 +70,8 @@ $(function() {
 		'unknown-domain': "Domain cannot be resolved."
 	};
 
+	var disabled_message = "Mail delivery for this person has not been enabled yet. Contact IAM for details.";
+
 	function feedback_text(k) {
 		if(k === undefined)
 			return '';
@@ -307,6 +309,9 @@ $(function() {
 		);
 		this.$compacted_mailbox = $(this.compacted_mailbox);
 
+		this.compacted_disabled = html('p', {'class': 'summary clickable', title: disabled_message}, "❌ Disabled");
+		this.$compacted_disabled = $(this.compacted_disabled);
+
 		/* Icons for the "expand" and "collapse" actions. */
 		this.compacted_img = html('div',
 			['img', {src: 'static/expand.png', alt: 'show', 'class': 'showimg'}]);
@@ -316,15 +321,19 @@ $(function() {
 		this.$img_container = $(this.img_container);
 
 		this.$img_container.click(function(){ self.toggle() });
+		this.$compacted_disabled.click(function(){ self.show() });
 		this.$compacted_mailbox.click(function(){ self.show() });
 		this.$compacted_labels.click(function(){ self.show() });
 
 		this.labels_container = html('td', {'class': 'column from', rowspan: 2}, this.compacted_labels);
 		this.$labels_container = $(this.labels_container);
 
-		this.mailbox_container = html('td', {'class': 'column to', rowspan: 2}, this.compacted_mailbox);
+		this.mailbox_container = html('div', this.compacted_mailbox);
 		this.$mailbox_container = $(this.mailbox_container);
 
+		this.disabled_container = html('div', this.compacted_disabled);
+		this.$disabled_container = $(this.disabled_container);
+
 		this.btn_container = html('td', {'class': 'column right', rowspan: 2});
 		this.$btn_container = $(this.btn_container);
 
@@ -335,7 +344,12 @@ $(function() {
 						['td', {'class': 'column left'},
 							['span', {'class': 'userTypeImage person'}]
 						],
-						this.labels_container, this.mailbox_container, this.btn_container
+						this.labels_container,
+						['td', {'class': 'column to', rowspan: 2},
+							this.mailbox_container,
+							this.disabled_container,
+						],
+						this.btn_container,
 					],
 					['tr',
 						['td', {'class': 'column left', style: 'vertical-align: bottom'},
@@ -380,6 +394,14 @@ $(function() {
 		this.$expanded_mailbox.hide();
 		this.$mailbox_container.append(this.expanded_mailbox);
 
+		this.expanded_disabled = html('div', {'class': 'expanded'},
+			['div', ['p', disabled_message]],
+			['div', this.feedback],
+		);
+		this.$expanded_disabled = $(this.expanded_disabled);
+		this.$expanded_disabled.hide();
+		this.$disabled_container.append(this.expanded_disabled);
+
 		var submit_btn = html('button', {type: 'button', 'class': 'saveButton', name: 'savePerson', title: "Store your changes"}, ['strong', "Save"]);
 		var reset_btn = html('button', {type: 'button', 'class': 'resetButton', name: 'resetPerson', title: "Restore to last saved values"}, "Reset");
 
@@ -389,7 +411,7 @@ $(function() {
 		this.$btn_container.append(this.expanded_btn);
 
 		onChange(this.$mailbox, function() {
-			setInputColor(self.$mailbox, self.person.mailbox, self.goodmailbox, self.badmailbox);
+			setInputColor(self.$mailbox, person.mailbox, self.goodmailbox, self.badmailbox);
 		});
 
 		$(reset_btn).click(function() {
@@ -399,11 +421,12 @@ $(function() {
 		});
 
 		$(submit_btn).click(function() {
+			var person = self.person;
 			var labels = [];
 			var addresses = [];
 			var postdata = {
 				labels: addresses,
-				mailbox: self.$mailbox.val()
+				mailbox: person.mailbox == null ? null : self.$mailbox.val(),
 			};
 			var labels_by_id = self.labels_by_id;
 			for(var k in labels_by_id) {
@@ -416,7 +439,8 @@ $(function() {
 				var notes = data.notes;
 				var note = notes.update;
 				if(note[0] == 'ok') {
-					self.setPerson(data.person);
+					person = data.person;
+					self.setPerson(person);
 					self.feedback.className = 'positive-feedback';
 					self.$feedback.text(feedback_text(note[1]));
 					self.hide();
@@ -462,14 +486,14 @@ $(function() {
 						self.badmailbox = postdata.mailbox;
 						self.$feedback.text(feedback_text(note[1]));
 					}
-					setInputColor(self.$mailbox, self.person.mailbox, self.goodmailbox, self.badmailbox);
+					setInputColor(self.$mailbox, person.mailbox, self.goodmailbox, self.badmailbox);
 				}
 			}
 			function failed(jqXHR, textStatus, errorThrown) {
 				if(jqXHR.getResponseHeader('Content-Type') === 'application/json')
 					success($.parseJSON(jqXHR.responseText));
 			}
-			var url = 'persons/' + self.person.anr + qnonce();
+			var url = 'persons/' + person.anr + qnonce();
 			$.ajax({
 				url: url,
 				data: JSON.stringify(postdata),
@@ -486,33 +510,36 @@ $(function() {
 
 	PersonWidget.prototype.show = function() {
 		this.jit();
-		this.$compacted_labels.slideUp('fast');    
-		this.$expanded_labels.slideDown('fast');    
+		this.$compacted_labels.slideUp('fast');
+		this.$expanded_labels.slideDown('fast');
 		this.$compacted_mailbox.slideUp('fast');
-		this.$expanded_mailbox.slideDown('fast');    
-		this.$expanded_btn.slideDown('fast');    
+		this.$expanded_mailbox.slideDown('fast');
+		this.$expanded_disabled.slideDown('fast');
+		this.$expanded_btn.slideDown('fast');
 		this.$compacted_img.hide();
 		this.$expanded_img.show();
 	}
 
 	PersonWidget.prototype.hide = function() {
 		this.jit();
-		this.$compacted_labels.slideDown('fast');    
-		this.$expanded_labels.slideUp('fast');    
+		this.$compacted_labels.slideDown('fast');
+		this.$expanded_labels.slideUp('fast');
 		this.$compacted_mailbox.slideDown('fast');
-		this.$expanded_mailbox.slideUp('fast');    
-		this.$expanded_btn.slideUp('fast');    
+		this.$expanded_mailbox.slideUp('fast');
+		this.$expanded_disabled.slideUp('fast');
+		this.$expanded_btn.slideUp('fast');
 		this.$compacted_img.show();
 		this.$expanded_img.hide();
 	}
 
 	PersonWidget.prototype.toggle = function() {
 		this.jit();
-		this.$compacted_labels.slideToggle('fast');    
-		this.$expanded_labels.slideToggle('fast');    
-		this.$compacted_mailbox.slideToggle('fast');    
-		this.$expanded_mailbox.slideToggle('fast');    
-		this.$expanded_btn.slideToggle('fast');    
+		this.$compacted_labels.slideToggle('fast');
+		this.$expanded_labels.slideToggle('fast');
+		this.$compacted_mailbox.slideToggle('fast');
+		this.$expanded_mailbox.slideToggle('fast');
+		this.$expanded_disabled.slideToggle('fast');
+		this.$expanded_btn.slideToggle('fast');
 		this.$compacted_img.toggle();
 		this.$expanded_img.toggle();
 	}
@@ -533,7 +560,14 @@ $(function() {
 			compacted_labels.appendChild(html('div', {'title': title}, i ? n : ['strong', n]));
 		});
 
-		this.$mailbox_address.text(person.mailbox);
+		if(person.mailbox == null) {
+			this.$mailbox_container.hide();
+			this.$disabled_container.show();
+		} else {
+			this.$mailbox_address.text(person.mailbox);
+			this.$mailbox_container.show();
+			this.$disabled_container.hide();
+		}
 	}
 
 	PersonWidget.prototype.setPerson = function(person) {
@@ -865,10 +899,10 @@ $(function() {
 	AliasWidget.prototype.show = function() {
 		this.jit();
 		this.$compacted_dst.slideUp('fast');
-		this.$expanded_dst.slideDown('fast');    
-		this.$compacted_address.slideUp('fast');    
-		this.$expanded_address.slideDown('fast');    
-		this.$expanded_btn.slideDown('fast');    
+		this.$expanded_dst.slideDown('fast');
+		this.$compacted_address.slideUp('fast');
+		this.$expanded_address.slideDown('fast');
+		this.$expanded_btn.slideDown('fast');
 		this.$compacted_img.hide();
 		this.$expanded_img.show();
 	}
@@ -876,21 +910,21 @@ $(function() {
 	AliasWidget.prototype.hide = function() {
 		this.jit();
 		this.$compacted_dst.slideDown('fast');
-		this.$expanded_dst.slideUp('fast');    
-		this.$compacted_address.slideDown('fast');    
-		this.$expanded_address.slideUp('fast');    
-		this.$expanded_btn.slideUp('fast');    
+		this.$expanded_dst.slideUp('fast');
+		this.$compacted_address.slideDown('fast');
+		this.$expanded_address.slideUp('fast');
+		this.$expanded_btn.slideUp('fast');
 		this.$compacted_img.show();
 		this.$expanded_img.hide();
 	}
 
 	AliasWidget.prototype.toggle = function() {
 		this.jit();
-		this.$compacted_dst.slideToggle('fast');    
-		this.$expanded_dst.slideToggle('fast');    
-		this.$compacted_address.slideToggle('fast');    
-		this.$expanded_address.slideToggle('fast');    
-		this.$expanded_btn.slideToggle('fast');    
+		this.$compacted_dst.slideToggle('fast');
+		this.$expanded_dst.slideToggle('fast');
+		this.$compacted_address.slideToggle('fast');
+		this.$expanded_address.slideToggle('fast');
+		this.$expanded_btn.slideToggle('fast');
 		this.$compacted_img.toggle();
 		this.$expanded_img.toggle();
 	}
